change log for gcc-testing (2010-05-19)

rtems-vc at rtems.org rtems-vc at rtems.org
Wed May 19 15:10:03 UTC 2010


 *jennifer*:
2010-05-19	Jennifer Averett <Jennifer.Averett at OARcorp.com>

	* ConfigFile.h, CoverageRanges.h, DesiredSymbols.h, Doxyfile,
	ObjdumpProcessor.h, ReportsBase.cc, ReportsBase.h, ReportsHtml.cc,
	ReportsHtml.h, ReportsText.cc, ReportsText.h, Target_lm32.h,
	Target_m68k.h, Target_powerpc.h, TraceList.h, qemu-log.h,
	rtemscov_header.h: Resolved doxygen warnings. Added a NoRange report
	which lists all symbols that are never accessed by an executable.

M  1.265  rtems-coverage/ChangeLog
M    1.3  rtems-coverage/ConfigFile.h
M    1.7  rtems-coverage/CoverageRanges.h
M    1.8  rtems-coverage/DesiredSymbols.h
M    1.3  rtems-coverage/Doxyfile
M   1.12  rtems-coverage/ObjdumpProcessor.h
M   1.10  rtems-coverage/ReportsBase.h
M   1.14  rtems-coverage/ReportsBase.cc
M   1.10  rtems-coverage/ReportsHtml.h
M   1.22  rtems-coverage/ReportsHtml.cc
M    1.7  rtems-coverage/ReportsText.h
M    1.8  rtems-coverage/ReportsText.cc
M    1.4  rtems-coverage/Target_lm32.h
M    1.2  rtems-coverage/Target_m68k.h
M    1.2  rtems-coverage/Target_powerpc.h
M    1.3  rtems-coverage/TraceList.h
M    1.2  rtems-coverage/qemu-log.h
M    1.2  rtems-coverage/rtemscov_header.h

diff -u gcc-testing/rtems-coverage/ChangeLog:1.264 gcc-testing/rtems-coverage/ChangeLog:1.265
--- gcc-testing/rtems-coverage/ChangeLog:1.264	Wed May 19 09:02:21 2010
+++ gcc-testing/rtems-coverage/ChangeLog	Wed May 19 09:47:12 2010
@@ -1,3 +1,12 @@
+2010-05-19	Jennifer Averett <Jennifer.Averett at OARcorp.com>
+
+	* ConfigFile.h, CoverageRanges.h, DesiredSymbols.h, Doxyfile,
+	ObjdumpProcessor.h, ReportsBase.cc, ReportsBase.h, ReportsHtml.cc,
+	ReportsHtml.h, ReportsText.cc, ReportsText.h, Target_lm32.h,
+	Target_m68k.h, Target_powerpc.h, TraceList.h, qemu-log.h,
+	rtemscov_header.h: Resolved doxygen warnings. Added a NoRange report
+	which lists all symbols that are never accessed by an executable.
+
 2010-05-19	Joel Sherrill <joel.sherrilL at OARcorp.com>
 
 	* covoar.cc: Add executable and coverage file extension parameters

diff -u gcc-testing/rtems-coverage/ConfigFile.h:1.2 gcc-testing/rtems-coverage/ConfigFile.h:1.3
--- gcc-testing/rtems-coverage/ConfigFile.h:1.2	Wed May 12 13:12:36 2010
+++ gcc-testing/rtems-coverage/ConfigFile.h	Wed May 19 09:47:12 2010
@@ -15,6 +15,11 @@
 
 namespace Configuration {
 
+  /*!
+   *  
+   *  This structure contains the configuration parameter
+   *  name and value pair.
+   */ 
   typedef struct {
     const char *option;
     const char *value;

diff -u gcc-testing/rtems-coverage/CoverageRanges.h:1.6 gcc-testing/rtems-coverage/CoverageRanges.h:1.7
--- gcc-testing/rtems-coverage/CoverageRanges.h:1.6	Fri May 14 12:26:35 2010
+++ gcc-testing/rtems-coverage/CoverageRanges.h	Wed May 19 09:47:12 2010
@@ -42,19 +42,54 @@
      *  This type defines the information kept for each range.
      */
     typedef struct {
+      /*!
+       *  This member contains an identification number for this 
+       *  coverage range.
+       */
       uint32_t          id;
+
+      /*!
+       *  This member contains the low address of this coverage 
+       *  range.
+       */
       uint32_t          lowAddress;
+
+      /*!
+       *  This member contains the source line associated with the 
+       *  low address for this coverage range.
+       */
       std::string       lowSourceLine;
+
+      /*!
+       * This member contains the high address for this coverage range.
+       */
       uint32_t          highAddress;
+
+      /*!
+       *  This member contains the high source line for this coverage range.
+       */
       std::string       highSourceLine;
+
+      /*!
+       * This member contains an instruction count for this coverage 
+       * address range.
+       */
       uint32_t          instructionCount;
+
+      /*!
+       *  This member contains the reason that this area was uncovered.
+       */
       uncoveredReason_t reason;
     } coverageRange_t;
 
     /*!
-     *  This member variable contains a list of CoverageRange instances.
+     *  This type contains a list of CoverageRange instances.
      */
     typedef std::list<coverageRange_t> ranges_t;
+
+    /*!
+     *  This member contains a list of the CoverageRange instances.
+     */
     ranges_t set;
 
     /*! 

diff -u gcc-testing/rtems-coverage/DesiredSymbols.h:1.7 gcc-testing/rtems-coverage/DesiredSymbols.h:1.8
--- gcc-testing/rtems-coverage/DesiredSymbols.h:1.7	Tue May 18 09:21:13 2010
+++ gcc-testing/rtems-coverage/DesiredSymbols.h	Wed May 19 09:47:12 2010
@@ -24,7 +24,7 @@
 namespace Coverage {
 
 
-  /*! @class Stats
+  /*! 
    * 
    *  This class defines the statistics that are tracked.
    */
@@ -188,6 +188,11 @@
      *  This map associates each symbol with its symbol information.
      */
     typedef std::map<std::string, SymbolInformation> symbolSet_t;
+
+    /*!
+     *  This variable contains a map of ymbol sets for each 
+     *  symbol in the system keyed on the symbol name.
+     */
     symbolSet_t set;
 
     /*! 

diff -u gcc-testing/rtems-coverage/Doxyfile:1.2 gcc-testing/rtems-coverage/Doxyfile:1.3
--- gcc-testing/rtems-coverage/Doxyfile:1.2	Wed May 12 13:12:36 2010
+++ gcc-testing/rtems-coverage/Doxyfile	Wed May 19 09:47:12 2010
@@ -585,7 +585,7 @@
 # *.c *.cc *.cxx *.cpp *.c++ *.java *.ii *.ixx *.ipp *.i++ *.inl *.h *.hh *.hxx
 # *.hpp *.h++ *.idl *.odl *.cs *.php *.php3 *.inc *.m *.mm *.py *.f90
 
-FILE_PATTERNS          =
+FILE_PATTERNS          = *.h
 
 # The RECURSIVE tag can be used to turn specify whether or not subdirectories
 # should be searched for input files as well. Possible values are YES and NO.

diff -u gcc-testing/rtems-coverage/ObjdumpProcessor.h:1.11 gcc-testing/rtems-coverage/ObjdumpProcessor.h:1.12
--- gcc-testing/rtems-coverage/ObjdumpProcessor.h:1.11	Tue May 18 09:21:13 2010
+++ gcc-testing/rtems-coverage/ObjdumpProcessor.h	Wed May 19 09:47:12 2010
@@ -72,8 +72,17 @@
 
     } objdumpLine_t;
 
+    /*!
+     *  This object defines a list of object dump lines
+     *  for a file.
+     */
     typedef std::list<objdumpLine_t> objdumpLines_t;
 
+   
+    /*!
+     *  This object defines a list of instruction addresses
+     *  that will be extracted from the objdump file.
+     */ 
     typedef std::list<uint32_t> objdumpFile_t;
 
     /*!
@@ -135,6 +144,10 @@
 
   private:
 
+    /*!
+     *  This variable consists of a list of all instruction addresses
+     *  extracted from the obj dump file.
+     */
     objdumpFile_t       objdumpList;
 
     /*!

diff -u gcc-testing/rtems-coverage/ReportsBase.cc:1.13 gcc-testing/rtems-coverage/ReportsBase.cc:1.14
--- gcc-testing/rtems-coverage/ReportsBase.cc:1.13	Mon May 17 14:03:53 2010
+++ gcc-testing/rtems-coverage/ReportsBase.cc	Wed May 19 09:47:12 2010
@@ -84,6 +84,14 @@
   return OpenFile(fileName);
 }
 
+FILE* ReportsBase::OpenNoRangeFile(
+  const char* const fileName
+)
+{
+  return OpenFile(fileName);
+}
+
+
 FILE* ReportsBase::OpenSizeFile(
   const char* const fileName
 )
@@ -127,6 +135,13 @@
   CloseFile( aFile );
 }
 
+void  ReportsBase::CloseNoRangeFile(
+  FILE*  aFile
+)
+{
+  CloseFile( aFile );
+}
+
 void  ReportsBase::CloseSizeFile(
   FILE*  aFile
 )
@@ -289,7 +304,17 @@
   FILE*                                           report;
   Coverage::CoverageRanges::ranges_t::iterator    ritr;
   Coverage::CoverageRanges*                       theRanges;
-  unsigned int                                    count;
+  unsigned int                                    count, count2;
+  FILE*                                           NoRangeFile;
+  std::string                                     NoRangeName;
+
+  // Open special file that captures NoRange informaiton
+  NoRangeName = "no_range_";
+  NoRangeName +=  fileName;
+  NoRangeFile = OpenNoRangeFile ( NoRangeName.c_str() );
+  if (!NoRangeFile) {
+    return;
+  }
 
   // Open the coverage report file.
   report = OpenCoverageFile( fileName );
@@ -310,7 +335,7 @@
     // desired symbols list or with the executables so put something
     // in the report.
     if (theRanges == NULL) {
-      putCoverageNoRange( report, count, ditr->first );
+      putCoverageNoRange( report, NoRangeFile, count, ditr->first );
       count++;
     }  else if (!theRanges->set.empty()) {
 
@@ -323,7 +348,9 @@
     }
   }
 
+  CloseNoRangeFile( NoRangeFile );
   CloseCoverageFile( report );
+
 }
 
 /*

diff -u gcc-testing/rtems-coverage/ReportsHtml.h:1.9 gcc-testing/rtems-coverage/ReportsHtml.h:1.10
--- gcc-testing/rtems-coverage/ReportsHtml.h:1.9	Fri May 14 12:26:35 2010
+++ gcc-testing/rtems-coverage/ReportsHtml.h	Wed May 19 09:47:12 2010
@@ -19,6 +19,10 @@
 
 namespace Coverage {
 
+/*!
+ *   This class contains all methods and data necessary to
+ *   do all of the HTML style reports.
+ */
 class ReportsHtml: public ReportsBase {
 
   public:
@@ -66,50 +70,77 @@
 
   protected:
 
+    /*!
+     *  This variable tracks the annotated state at the time the 
+     *  last line was output.  This allows the text formating to change
+     *  based upon the type of lines being put out: source code or assembly
+     *  object dump line....
+     */
     AnnotatedLineState_t lastState_m;
 
+    /* Inherit documentation from base class. */ 
     virtual FILE* OpenAnnotatedFile(
       const char* const fileName
     );
 
+    /* Inherit documentation from base class. */ 
     virtual FILE* OpenBranchFile(
       const char* const fileName,
       bool              hasBranches
     );
 
+    /* Inherit documentation from base class. */ 
     virtual FILE* OpenCoverageFile(
       const char* const fileName
     );
 
+    /* Inherit documentation from base class. */ 
+    FILE* OpenNoRangeFile(
+      const char* const fileName
+    );
+
+    /* Inherit documentation from base class. */ 
     virtual FILE* OpenSizeFile(
       const char* const fileName
     );
 
+    /* Inherit documentation from base class. */ 
     virtual FILE* OpenSymbolSummaryFile(
       const char* const fileName
     );
 
+    /* Inherit documentation from base class. */ 
     virtual void CloseAnnotatedFile(
       FILE*  aFile
     );
 
+    /* Inherit documentation from base class. */ 
     virtual void CloseBranchFile(
       FILE*  aFile,
       bool   hasBranches
     );
 
+    /* Inherit documentation from base class. */ 
     virtual void CloseCoverageFile(
       FILE*  aFile
     );
 
+    /* Inherit documentation from base class. */ 
+    void CloseNoRangeFile(
+      FILE*  aFile
+    );
+
+    /* Inherit documentation from base class. */ 
     virtual void CloseSizeFile(
       FILE*  aFile
     );
 
+    /* Inherit documentation from base class. */ 
     virtual void CloseSymbolSummaryFile(
       FILE*  aFile
     );
 
+    /* Inherit documentation from base class. */ 
     virtual void PutAnnotatedLine( 
       FILE*                aFile, 
       AnnotatedLineState_t state, 
@@ -117,10 +148,12 @@
       uint32_t             id 
     );
 
+    /* Inherit documentation from base class. */ 
     virtual bool PutNoBranchInfo(
       FILE* report
     );
 
+    /* Inherit documentation from base class. */ 
     virtual bool PutBranchEntry(
       FILE*                                            report,
       unsigned int                                     number,
@@ -128,12 +161,15 @@
       Coverage::CoverageRanges::ranges_t::iterator     rangePtr
     );
 
+    /* Inherit documentation from base class. */ 
     virtual void putCoverageNoRange(
       FILE*        report,
+      FILE*        noRangeFile,
       unsigned int number,
       std::string  symbol
     );
 
+    /* Inherit documentation from base class. */ 
     virtual bool PutCoverageLine(
       FILE*                                           report,
       unsigned int                                    number,
@@ -141,6 +177,7 @@
       Coverage::CoverageRanges::ranges_t::iterator    ritr
     );
 
+    /* Inherit documentation from base class. */ 
     virtual bool PutSizeLine(
       FILE*                                           report,
       unsigned int                                    number,
@@ -148,16 +185,19 @@
       Coverage::CoverageRanges::ranges_t::iterator    range
     );
 
+    /* Inherit documentation from base class. */ 
     virtual bool PutSymbolSummaryLine(
       FILE*                                           report,
       unsigned int                                    number,
       Coverage::DesiredSymbols::symbolSet_t::iterator symbol
     );
 
+    /* Inherit documentation from base class. */ 
     virtual FILE* OpenFile(
       const char* const fileName
     );
 
+    /* Inherit documentation from base class. */ 
     virtual bool WriteExplationFile(
       const char*                  fileName,
       const Coverage::Explanation* explanation

diff -u gcc-testing/rtems-coverage/ReportsHtml.cc:1.21 gcc-testing/rtems-coverage/ReportsHtml.cc:1.22
--- gcc-testing/rtems-coverage/ReportsHtml.cc:1.21	Mon May 17 14:35:57 2010
+++ gcc-testing/rtems-coverage/ReportsHtml.cc	Wed May 19 09:47:12 2010
@@ -117,6 +117,7 @@
 
     fprintf(
       aFile,
+      "<title>Annotated Report</title>\n"
       "<pre class=\"heading-title\">Annotated Report</pre>\n"
       "<body>\n"
       "<pre class=\"code\">\n"
@@ -139,6 +140,7 @@
       // Put header information into the file
       fprintf(
         aFile,
+        "<title>Branch Report</title\n"
         "<pre class=\"heading-title\">Branch Report</pre>\n"
         "<body>\n"
          "<table class=\"covoar table-autosort:0 table-autofilter table-stripeclass:covoar-tr-odd"
@@ -172,6 +174,7 @@
     // Put header information into the file
     fprintf(
       aFile,
+        "<title>Coverage Report</title>\n"
         "<pre class=\"heading-title\">Coverage Report</pre>\n"
         "<body>\n"
       "<table class=\"covoar table-autosort:0 table-autofilter table-stripeclass:covoar-tr-odd"
@@ -192,6 +195,36 @@
     return aFile;
   }
 
+  FILE* ReportsHtml::OpenNoRangeFile(
+    const char* const fileName
+  )
+  {
+    FILE *aFile;
+
+    // Open the file
+    aFile = OpenFile(fileName);
+
+    // Put header information into the file
+    fprintf(
+      aFile,
+        "<title> Report</title>\n"
+        "<pre class=\"heading-title\">No Range Report</pre>\n"
+        "<body>\n"
+      "<table class=\"covoar table-autosort:0 table-autofilter table-stripeclass:covoar-tr-odd"
+           TABLE_HEADER_CLASS "\">\n"
+      "<thead>\n"
+      "<tr>\n"
+      "<th class=\"table-sortable:default\" align=\"left\">Symbol</th>\n"
+      "</tr>\n"
+      "</thead>\n"
+      "<tbody>\n"
+     );
+
+    return aFile;
+   }
+
+
+
   FILE*  ReportsHtml::OpenSizeFile(
     const char* const fileName
   )
@@ -204,6 +237,7 @@
     // Put header information into the file
     fprintf(
       aFile,
+      "<title>Size Report</title>\n"
       "<pre class=\"heading-title\">Size Report</pre>\n"
       "<body>\n"
       "<table class=\"covoar table-autosort:0 table-autofilter table-stripeclass:covoar-tr-odd"
@@ -232,6 +266,7 @@
     // Put header information into the file
     fprintf(
       aFile,
+      "<title>Symbol Summary Report</title>\n"
       "<pre class=\"heading-title\">Symbol Summary Report</pre>\n"
       "<body>\n"
       "<table class=\"covoar table-autosort:0 table-autofilter table-stripeclass:covoar-tr-odd"
@@ -344,6 +379,8 @@
     // Mark the background color different for odd and even lines.
     if ( ( count%2 ) != 0 )
       fprintf( report, "<tr class=\"covoar-tr-odd\">\n");
+    else
+      fprintf( report, "<tr>\n");
 
     // symbol
     fprintf( 
@@ -432,6 +469,7 @@
 
   void ReportsHtml::putCoverageNoRange(
     FILE*         report,
+    FILE*         noRangeFile,
     unsigned int  count,
     std::string   symbol
   )
@@ -448,8 +486,13 @@
     );
 
     // Mark the background color different for odd and even lines.
-    if ( ( count%2 ) != 0 )
+    if ( ( count%2 ) != 0 ){
       fprintf( report, "<tr class=\"covoar-tr-odd\">\n");
+      fprintf( noRangeFile,  "<tr class=\"covoar-tr-odd\">\n");
+    } else {
+      fprintf( report, "<tr>\n");
+      fprintf( noRangeFile,  "<tr>\n");
+    }
 
     // symbol
     fprintf( 
@@ -457,6 +500,11 @@
       "<td class=\"covoar-td\" align=\"center\">%s</td>\n",     
       symbol.c_str()
     );
+    fprintf( 
+      noRangeFile, 
+      "<td class=\"covoar-td\" align=\"center\">%s</td>\n",     
+      symbol.c_str()
+    );
 
     // starting line
     fprintf( 
@@ -486,6 +534,7 @@
     WriteExplationFile( "NotReferenced.html", &explanation );
 
     fprintf( report, "</tr>\n");
+    fprintf( noRangeFile, "</tr>\n");
   }
 
   bool ReportsHtml::PutCoverageLine(
@@ -501,6 +550,8 @@
     // Mark the background color different for odd and even lines.
     if ( ( count%2 ) != 0 )
       fprintf( report, "<tr class=\"covoar-tr-odd\">\n");
+    else
+      fprintf( report, "<tr>\n");
 
     // symbol
     fprintf( 
@@ -573,6 +624,8 @@
     // Mark the background color different for odd and even lines.
     if ( ( count%2 ) != 0 )
       fprintf( report, "<tr class=\"covoar-tr-odd\">\n");
+    else
+      fprintf( report, "<tr>\n");
 
     // size
     fprintf( 
@@ -610,6 +663,8 @@
     // Mark the background color different for odd and even lines.
     if ( ( count%2 ) != 0 )
       fprintf( report, "<tr class=\"covoar-tr-odd\">\n");
+    else
+      fprintf( report, "<tr>\n");
 
     // symbol
     fprintf( 
@@ -760,6 +815,24 @@
     CloseFile(aFile);
   }
 
+  void ReportsHtml::CloseNoRangeFile(
+    FILE*  aFile
+  )
+  {
+    fprintf(
+      aFile,
+      TABLE_FOOTER
+      "</tbody>\n"
+      "</table>\n" 
+      "</pre>\n" 
+      "</body>\n"
+      "</html>"
+    );
+
+    CloseFile(aFile);
+  }
+
+
   void ReportsHtml::CloseSizeFile(
     FILE*  aFile
   )

diff -u gcc-testing/rtems-coverage/ReportsText.h:1.6 gcc-testing/rtems-coverage/ReportsText.h:1.7
--- gcc-testing/rtems-coverage/ReportsText.h:1.6	Fri May 14 12:26:35 2010
+++ gcc-testing/rtems-coverage/ReportsText.h	Wed May 19 09:47:12 2010
@@ -18,6 +18,10 @@
 
 namespace Coverage {
 
+/*!
+ *   This class contains all methods and data necessary to
+ *   produce all text style reports.
+ */
 class ReportsText: public ReportsBase {
 
   public:
@@ -76,6 +80,7 @@
 
     virtual void putCoverageNoRange(
       FILE*        report,
+      FILE*        noRangeFile,
       unsigned int number,
       std::string  symbol
     );

diff -u gcc-testing/rtems-coverage/ReportsText.cc:1.7 gcc-testing/rtems-coverage/ReportsText.cc:1.8
--- gcc-testing/rtems-coverage/ReportsText.cc:1.7	Fri May 14 13:49:57 2010
+++ gcc-testing/rtems-coverage/ReportsText.cc	Wed May 19 09:47:12 2010
@@ -115,6 +115,7 @@
 
 void ReportsText::putCoverageNoRange(
   FILE*         report,
+  FILE*         noRangeFile,
   unsigned int  number,
   std::string   symbol
 )
@@ -131,6 +132,7 @@
         "============================================\n",
         symbol.c_str()
       );
+      fprintf( noRangeFile, "%s\n", symbol.c_str() );
 }
 
 bool ReportsText::PutCoverageLine(

diff -u gcc-testing/rtems-coverage/Target_lm32.h:1.3 gcc-testing/rtems-coverage/Target_lm32.h:1.4
--- gcc-testing/rtems-coverage/Target_lm32.h:1.3	Thu Apr 29 14:12:31 2010
+++ gcc-testing/rtems-coverage/Target_lm32.h	Wed May 19 09:47:12 2010
@@ -18,7 +18,7 @@
 
 namespace Target {
 
-  /*! @class TargetBase
+  /*!
    *
    *  This class is the class for the m68k Target.
    *

diff -u gcc-testing/rtems-coverage/Target_m68k.h:1.1 gcc-testing/rtems-coverage/Target_m68k.h:1.2
--- gcc-testing/rtems-coverage/Target_m68k.h:1.1	Thu Apr 22 14:14:07 2010
+++ gcc-testing/rtems-coverage/Target_m68k.h	Wed May 19 09:47:12 2010
@@ -18,7 +18,7 @@
 
 namespace Target {
 
-  /*! @class TargetBase
+  /*!
    *
    *  This class is the class for the m68k Target.
    *

diff -u gcc-testing/rtems-coverage/Target_powerpc.h:1.1 gcc-testing/rtems-coverage/Target_powerpc.h:1.2
--- gcc-testing/rtems-coverage/Target_powerpc.h:1.1	Thu Apr 22 14:14:07 2010
+++ gcc-testing/rtems-coverage/Target_powerpc.h	Wed May 19 09:47:12 2010
@@ -18,7 +18,7 @@
 
 namespace Target {
 
-  /*! @class TargetBase
+  /*!
    *
    *  This class is the class for the powerpc target.
    *

diff -u gcc-testing/rtems-coverage/TraceList.h:1.2 gcc-testing/rtems-coverage/TraceList.h:1.3
--- gcc-testing/rtems-coverage/TraceList.h:1.2	Fri Apr 23 13:57:18 2010
+++ gcc-testing/rtems-coverage/TraceList.h	Wed May 19 09:47:12 2010
@@ -25,6 +25,10 @@
 
   public:
 
+    /*!
+     *  This enumberated type defines an exit reason
+     *  for the end of a section.
+     */
     typedef enum {
       EXIT_REASON_BRANCH_TAKEN,
       EXIT_REASON_BRANCH_NOT_TAKEN,
@@ -35,8 +39,22 @@
      *  This type defines the information kept for each range.
      */
     typedef struct {
+      /*!
+       *  This member variable contains the low address for the
+       *  trace range.
+       */
       uint32_t          lowAddress;
+
+      /*!
+       *  This member variable contains the length of the trace
+       *  range.
+       */
       uint16_t          length;
+
+      /*!
+       *  This member variable contains the reason that this
+       *  trace range ended.
+       */
       exitReason_t      exitReason;
     } traceRange_t;
 
@@ -44,6 +62,11 @@
      *  This member variable contains a list of CoverageRange instances.
      */
     typedef std::list<traceRange_t> ranges_t;
+
+    /*!
+     *  This member variable contains a list of coverageRange
+     *  instaces.
+     */
     ranges_t set;
 
     /*! 

diff -u gcc-testing/rtems-coverage/qemu-log.h:1.1 gcc-testing/rtems-coverage/qemu-log.h:1.2
--- gcc-testing/rtems-coverage/qemu-log.h:1.1	Thu Apr 22 14:17:01 2010
+++ gcc-testing/rtems-coverage/qemu-log.h	Wed May 19 09:47:12 2010
@@ -13,6 +13,10 @@
 #define QEMU_LOG_SECTION_END    "----------------"
 #define QEMU_LOG_IN_KEY         "IN: "
 
+/*!
+ *   This structure breaks apart the log line information
+ *   into the components address, instruction and data.
+ */
 typedef struct {
   unsigned long address;
   char          instruction[10];

diff -u gcc-testing/rtems-coverage/rtemscov_header.h:1.1 gcc-testing/rtems-coverage/rtemscov_header.h:1.2
--- gcc-testing/rtems-coverage/rtemscov_header.h:1.1	Fri Sep 18 09:28:46 2009
+++ gcc-testing/rtems-coverage/rtemscov_header.h	Wed May 19 09:47:12 2010
@@ -15,6 +15,11 @@
 
 #define MAX_DESC_STR 32
 
+/*!
+ *
+ *   This structure contains XXX
+ */
+
 typedef struct prof_header_s{
   /** the version of header file */
   int ver;


 *jennifer*:
2010-05-19	Jennifer Averett <Jennifer.Averett at OARcorp.com>

	* Target_powerpc.cc: Added missing branch instructions to table of
	branch instructions for powerpc.

M  1.266  rtems-coverage/ChangeLog
M    1.3  rtems-coverage/Target_powerpc.cc

diff -u gcc-testing/rtems-coverage/ChangeLog:1.265 gcc-testing/rtems-coverage/ChangeLog:1.266
--- gcc-testing/rtems-coverage/ChangeLog:1.265	Wed May 19 09:47:12 2010
+++ gcc-testing/rtems-coverage/ChangeLog	Wed May 19 10:03:43 2010
@@ -1,5 +1,10 @@
 2010-05-19	Jennifer Averett <Jennifer.Averett at OARcorp.com>
 
+	* Target_powerpc.cc: Added missing branch instructions to table of
+	branch instructions for powerpc.
+
+2010-05-19	Jennifer Averett <Jennifer.Averett at OARcorp.com>
+
 	* ConfigFile.h, CoverageRanges.h, DesiredSymbols.h, Doxyfile,
 	ObjdumpProcessor.h, ReportsBase.cc, ReportsBase.h, ReportsHtml.cc,
 	ReportsHtml.h, ReportsText.cc, ReportsText.h, Target_lm32.h,

diff -u gcc-testing/rtems-coverage/Target_powerpc.cc:1.2 gcc-testing/rtems-coverage/Target_powerpc.cc:1.3
--- gcc-testing/rtems-coverage/Target_powerpc.cc:1.2	Fri Apr 30 07:43:14 2010
+++ gcc-testing/rtems-coverage/Target_powerpc.cc	Wed May 19 10:03:43 2010
@@ -19,12 +19,19 @@
   Target_powerpc::Target_powerpc( std::string targetName ):
     TargetBase( targetName )
   {
+    branchInstructions.push_back("b");
+    branchInstructions.push_back("ba");
+    branchInstructions.push_back("bl");
+    branchInstructions.push_back("bla");
     branchInstructions.push_back("bc");
     branchInstructions.push_back("bca");
     branchInstructions.push_back("bcl");
     branchInstructions.push_back("bcla");
     branchInstructions.push_back("bcctr");
     branchInstructions.push_back("bcctrl");
+    branchInstructions.push_back("bclr");
+    branchInstructions.push_back("bclrl");
+
   
     branchInstructions.sort();    
   }



diff -u gcc-testing/rtems-coverage/ReportsBase.h:1.9 gcc-testing/rtems-coverage/ReportsBase.h:1.10
--- gcc-testing/rtems-coverage/ReportsBase.h:1.9	Fri May 14 12:26:35 2010
+++ gcc-testing/rtems-coverage/ReportsBase.h	Wed May 19 09:47:12 2010
@@ -19,7 +19,11 @@
 
 namespace Coverage {
 
-
+/*!
+ *   This class contains the base information to create a report 
+ *   set.  The report set may be text based, html based or some
+ *   other format to be defined at a future time.
+ */
 class ReportsBase {
 
   public:
@@ -89,8 +93,6 @@
      *  This method returns the unique extension for the Report
      *  type.  If the extension is ".txt" files will be 
      *  named "annotated.txt", "branch.txt" ......
-     *
-     *  @param[in] fileName identifies the report file name
      */
     std::string ReportExtension() { return reportExtension_m; }
 
@@ -153,6 +155,16 @@
     virtual FILE* OpenCoverageFile(
       const char* const fileName
     );
+    
+    /*!
+     *  This method opens a report file and verifies that it opened.
+     *  Then appends any necessary header information onto the file.
+     *
+     *  @param[in] fileName identifies the report file name
+     */
+    virtual FILE* OpenNoRangeFile(
+      const char* const fileName
+    );
 
     /*!
      *  This method opens a report file and verifies that it opened.
@@ -177,7 +189,7 @@
     /*!
      *  This method Closes a report file. 
      *
      *  @param[in] fileName identifies the report file name
      */
     void CloseFile(
       FILE*  aFile
@@ -187,7 +199,7 @@
      *  This method puts any necessary footer information into
      *  the report then closes the file.
      *
      *  @param[in] fileName identifies the report file name
      */
     virtual void CloseAnnotatedFile(
       FILE*  aFile
@@ -197,7 +209,7 @@
      *  This method puts any necessary footer information into
      *  the report then closes the file.
      *
      *  @param[in] fileName identifies the report file name
      *  @param[in] hasBranches indicates if there are branches to report
      */
     virtual void CloseBranchFile(
@@ -209,7 +221,7 @@
      *  This method puts any necessary footer information into
      *  the report then closes the file.
      *
      *  @param[in] fileName identifies the report file name
      */
     virtual void CloseCoverageFile(
       FILE*  aFile
@@ -219,7 +231,17 @@
      *  This method puts any necessary footer information into
      *  the report then closes the file.
      *
-     *  @param[in] fileName identifies the report file name
+     *  @param[in] aFile identifies the report file name
+     */
+    void  CloseNoRangeFile(
+      FILE*  aFile
+    );
+
+    /*!
+     *  This method puts any necessary footer information into
+     *  the report then closes the file.
+     *
+     *  @param[in] aFile identifies the report file name
      */
     virtual void CloseSizeFile(
       FILE*  aFile
@@ -229,7 +251,7 @@
      *  This method puts any necessary footer information into
      *  the report then closes the file.
      *
      *  @param[in] fileName identifies the report file name
      */
     virtual void CloseSymbolSummaryFile(
       FILE*  aFile
@@ -239,7 +261,10 @@
      *  This method puts any necessary footer information into
      *  the report then closes the file.
      *
-     *  @param[in] fileName identifies the report file name
+     *  @param[in] aFile identifies the report file name
+     *  @param[in] state identifies the state machine state
+     *  @param[in] line identifies the string to print  
+     *  @param[in] id identifies the branch or range id.
      */
     virtual void PutAnnotatedLine( 
       FILE*                aFile, 
@@ -252,7 +277,7 @@
      *  This method puts any necessary footer information into
      *  the report then closes the file.
      *
-     *  @param[in] fileName identifies the report file name
+     *  @param[in] report identifies the report file name
      */
     virtual bool PutNoBranchInfo(
       FILE* report
@@ -261,7 +286,10 @@
     /*!
      *  This method puts a branch entry into the branch report. 
      *
-     *  @param[in] fileName identifies the report file name
+     *  @param[in] report identifies the report file name
+     *  @param[in] number identifies the line number.
+     *  @param[in] symbolPtr is a pointer to the symbol information
+     *  @param[in] rangePtr is a pointer to the range information.
      */
     virtual bool PutBranchEntry(
       FILE*                                            report,
@@ -274,10 +302,13 @@
      *  This method reports when no range is available for 
      *  a symbol in the coverage report.
      *
-     *  @param[in] fileName identifies the report file name
+     *  @param[in] report identifies the report file name
+     *  @param[in] number identifies the line number.
+     *  @param[in] symbol is a pointer to the symbol information
      */
     virtual void putCoverageNoRange(
       FILE*        report,
+      FILE*        noRangeFile,
       unsigned int number,
       std::string  symbol
     )=0;
@@ -285,7 +316,10 @@
     /*!
      *  This method puts a line in the coverage report.
      *
-     *  @param[in] fileName identifies the report file name
+     *  @param[in] report identifies the report file name
+     *  @param[in] number identifies the line number.
+     *  @param[in] ditr is a iterator to the symbol information
+     *  @param[in] ritr is a iterator to the range information.
      */
     virtual bool PutCoverageLine(
       FILE*                                           report,
@@ -297,7 +331,10 @@
     /*!
      *  This method method puts a line into the size report.
      *
-     *  @param[in] fileName identifies the size report file name
+     *  @param[in] report identifies the size report file name
+     *  @param[in] number identifies the line number.
+     *  @param[in] symbol is a pointer to the symbol information
+     *  @param[in] range is a iterator to the range information.
      */
     virtual bool PutSizeLine(
       FILE*                                           report,
@@ -309,7 +346,9 @@
     /*!
      *  This method method puts a line into the symbol summary report.
      *
-     *  @param[in] fileName identifies the report file name
+     *  @param[in] report identifies the report file name
+     *  @param[in] number identifies the line number.
+     *  @param[in] symbol is a pointer to the symbol information
      */
     virtual bool PutSymbolSummaryLine(
       FILE*                                           report,
@@ -318,6 +357,10 @@
     )=0;
 };
 
+/*!
+ *  This method iterates over all report set types and generates
+ *  all reports.
+ */
 void GenerateReports();
 
 }
@@ -177,7 +189,7 @@
      *  This method Closes a report file. 
      *
-     *  @param[in] fileName identifies the report file name
+     *  @param[in] aFile identifies the report file name
      */
     void CloseFile(
@@ -187,7 +199,7 @@
      *  the report then closes the file.
      *
-     *  @param[in] fileName identifies the report file name
+     *  @param[in] aFile identifies the report file name
      */
     virtual void CloseAnnotatedFile(
@@ -197,7 +209,7 @@
      *  the report then closes the file.
      *
-     *  @param[in] fileName identifies the report file name
+     *  @param[in] aFile identifies the report file name
      *  @param[in] hasBranches indicates if there are branches to report
      */
@@ -209,7 +221,7 @@
      *  the report then closes the file.
      *
-     *  @param[in] fileName identifies the report file name
+     *  @param[in] aFile identifies the report file name
      */
     virtual void CloseCoverageFile(
@@ -229,7 +251,7 @@
      *  the report then closes the file.
      *
-     *  @param[in] fileName identifies the report file name
+     *  @param[in] aFile identifies the report file name
      */
     virtual void CloseSymbolSummaryFile(

--

Generated by Deluxe Loginfo [http://www.codewiz.org/projects/index.html#loginfo] 2.122 by Bernardo Innocenti <bernie at develer.com>
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.rtems.org/pipermail/vc/attachments/20100519/c81b88ce/attachment.html>


More information about the vc mailing list